pub struct SabreTransactionHandler { /* private fields */ }Expand description
Handles Sabre Transactions
This handler implements the Sawtooth TransactionHandler trait, in order to execute Sabre transaction payloads. These payloads include on-chain smart contracts executed in a WebAssembly virtual machine.
WebAssembly (Wasm) is a stack-based virtual machine newly implemented in major browsers. It is well-suited for the purposes of smart contract execution due to its sandboxed design, growing popularity, and tool support.
Implementations
Sourceimpl SabreTransactionHandler
impl SabreTransactionHandler
Sourcepub fn new(
admin_permissions: Box<dyn AdminPermission>,
) -> SabreTransactionHandler
pub fn new( admin_permissions: Box<dyn AdminPermission>, ) -> SabreTransactionHandler
Constructs a new SabreTransactionHandler